This crate contains the proc macros used by docify.
Macros
- compile_
markdown - Allows you to use
docify_clone::embed!(..)within markdown source files via HTML comments and compiles the result for you (at compile-time). - embed
- Embeds the specified item from the specified source file in a rust doc example, with pretty formatting enabled.
- embed_
run - Exactly like
docify_clone::embed!(..)in every way except the generated examples are also run automatically as rust doc examples (ignoreis not included). - set_
git_ fallback
Attribute Macros
- export
- Marks an item for export, making it available for embedding as a rust doc example via
docify_clone::embed!(..)ordocify::embed_run!(..). - export_
content - Like
#[docify_clone::export]but only exports the inner contents of whatever item the attribute is attached to.