embed_run!() { /* proc-macro */ }Expand description
Exactly like docify_clone::embed!(..) in every way except the generated
examples are also run automatically as rust doc examples (ignore is not included).
Other than this fact all of the usual docs and syntax and behaviors for
docify_clone::embed!(..) also apply to this macro.